@@ -1,6 +1,7 @@
-use crate::{id::Id, util::MapWithMut};
+use crate::id::Id;
 use fxhash::FxHashMap;
 use swc_atoms::js_word;
+use swc_common::util::take::Take;
 use swc_ecma_ast::*;
 use swc_ecma_utils::private_ident;
 use swc_ecma_visit::{noop_visit_mut_type, VisitMut, VisitMutWith};
